==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/mixer/adapter/signalfx/MetricConfigFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.signalfx;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class MetricConfigFluentImpl<A extends MetricConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements MetricConfigFluent<A>{

    private String name;
    private me.snowdrop.istio.mixer.adapter.signalfx.Type type;

    public MetricConfigFluentImpl(){
    }
    public MetricConfigFluentImpl(MetricConfig instance){
            this.withName(instance.getName()); 
            this.withType(instance.getType()); 
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public me.snowdrop.istio.mixer.adapter.signalfx.Type getType(){
            return this.type;
    }

    public A withType(me.snowdrop.istio.mixer.adapter.signalfx.Type type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            MetricConfigFluentImpl that = (MetricConfigFluentImpl) o;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }




}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/signalfx/MetricConfigFluentImpl.java <==
package me.snowdrop.istio.mixer.adapter.signalfx;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class MetricConfigFluentImpl<A extends MetricConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements MetricConfigFluent<A>{

    private String name;
    private me.snowdrop.istio.mixer.adapter.signalfx.Type type;

    public MetricConfigFluentImpl(){
    }
    public MetricConfigFluentImpl(MetricConfig instance){
            this.withName(instance.getName()); 
            this.withType(instance.getType()); 
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public A withNewName(String arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1){
            return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1){
            return (A)withName(new String(arg1));
    }

    public me.snowdrop.istio.mixer.adapter.signalfx.Type getType(){
            return this.type;
    }

    public A withType(me.snowdrop.istio.mixer.adapter.signalfx.Type type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            MetricConfigFluentImpl that = (MetricConfigFluentImpl) o;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }




}
